@@ -96,7 +96,7 @@ class AtroposN4InputSpec(CommandLineInputSpec):
 
     brainmask_file = File(
         exists=True,
-        desc='brain_file',
+        desc='brainmask_file',
         mandatory=True, position=2, argstr="-x %s")
 
     numberOfClasses = traits.Int(
@@ -130,18 +130,39 @@ class AtroposN4OutputSpec(TraitedSpec):
 
 
 class AtroposN4(CommandLine):
-    """
-    Description:
-        Wrap of antsAtroposN4.sh
-        Requires PATH to ANTS Scripts added
-
+    """Description: Wrap of antsAtroposN4.sh
 
     Inputs:
 
+        Mandatory:
+
+            dimension
+                Int, default=3 , 'Dimension'
+
+            brain_file
+                File, 'brain_file'
+
+            brainmask_file
+                File, 'brainmask_file'
+
+            numberOfClasses
+                Int, default=3, 'numberOfClasses'
+
+            priors
+                List of Files, 'priors'
+
+            template_file
+                String, default="tmp_%02d_allineate.nii.gz", 'template_file'
+
+        Optional:
+
+            out_pref:
+                String, default = "segment_", "output prefix"
+
     Outputs:
 
         brain_file:
-            type = File, exists=True, desc="extracted brain from AtroposN4.sh"
+            File, "extracted brain from AtroposN4.sh"
 
     """
     input_spec = AtroposN4InputSpec
@@ -169,6 +190,13 @@ class AtroposN4(CommandLine):
                 new_value.append(os.path.split(prior_file)[1])
 
             value = new_value
+
+        elif name == 'out_pref':
+
+            pth, fname, ext = split_f(self.inputs.brain_file)
+            value = fname+'_'
+            self.inputs.out_pref = value
+
         return super(AtroposN4, self)._format_arg(name, spec, value)
 
     def _list_outputs(self):
@@ -181,12 +209,19 @@ class AtroposN4(CommandLine):
         outputs['segmented_file'] = os.path.abspath(
             self.inputs.out_pref + "Segmentation.nii.gz")
 
+        print(self.inputs.out_pref)
+        print(self.inputs.out_pref + "SegmentationPosteriors*.nii.gz")
+
         seg_files = glob.glob(
             self.inputs.out_pref + "SegmentationPosteriors*.nii.gz")
 
+        print(seg_files)
+        print(self.inputs.priors)
+
         assert len(seg_files) == len(self.inputs.priors), \
-            "Error, there should {} SegmentationPosteriors".format(
-                len(self.inputs.priors))
+            "Error, there should {} SegmentationPosteriors ({})".format(
+                len(self.inputs.priors),
+                len(seg_files))
 
         outputs['segmented_files'] = [os.path.abspath(
             seg_file) for seg_file in seg_files]
@@ -194,6 +229,57 @@ class AtroposN4(CommandLine):
         return outputs
 
 
+def merge_masks(mask_csf_file, mask_wm_file, mask_gm_file, index_csf=1,
+                index_gm=2, index_wm=3):
+
+    import nibabel as nib
+    import numpy as np
+    import os.path as op
+
+    from nipype.utils.filemanip import split_filename as split_f
+
+    # csf (and init indexed_mask)
+    path, fname, ext = split_f(mask_csf_file)
+
+    mask_csf = nib.load(mask_csf_file)
+
+    mask_csf_data = mask_csf.get_data()
+
+    indexed_mask_data = np.zeros(shape=mask_csf_data.shape)
+
+    indexed_mask_data[mask_csf_data == 1] = index_csf
+
+    # gm
+    mask_gm = nib.load(mask_gm_file)
+
+    mask_gm_data = mask_gm.get_data()
+
+    assert np.all(indexed_mask_data.shape == mask_gm_data.shape)
+
+    indexed_mask_data[mask_gm_data == 1] = index_gm
+
+    # wm
+    mask_wm = nib.load(mask_wm_file)
+
+    mask_wm_data = mask_wm.get_data()
+
+    assert np.all(indexed_mask_data.shape == mask_wm_data.shape)
+
+    indexed_mask_data[mask_wm_data == 1] = index_wm
+
+    # creating indexed_mask
+    indexed_mask = nib.Nifti1Image(dataobj=indexed_mask_data,
+                                   affine=mask_csf.affine,
+                                   header=mask_csf.header)
+
+    # saving indexed_mask_file
+    indexed_mask_file = op.abspath(fname+"_indexed_mask"+ext)
+
+    nib.save(indexed_mask, indexed_mask_file)
+
+    return indexed_mask_file
+
+
 if __name__ == '__main__':
     # path_to = "/hpc/crise/meunier.d"
     path_to = "/hpc/crise/meunier.d/Data/Primavoice/test_pipeline_kepkee_crop"
